bindings property
Bindings<T>
get
bindings
inherited
All meta information about T necessary to plug arbitrary data types
into a Repository.
Implementation
Bindings<T> get bindings {
assert(
_bindings != null,
'You must either pass a Bindings object to the constructor or set it '
'later, which the SourceList does automatically.',
);
return _bindings!;
}
set
bindings
(Bindings<T> val)
inherited
Implementation
set bindings(Bindings<T> val) => _bindings = val;