getById method
Loads the instance of T whose primary key is found at
ReadOperation.itemId.
Implementation
@override
Future<ReadResult<T>> getById(ReadOperation<T> operation) =>
_guarded(() => _getById(operation), operation);
Loads the instance of T whose primary key is found at
ReadOperation.itemId.
@override
Future<ReadResult<T>> getById(ReadOperation<T> operation) =>
_guarded(() => _getById(operation), operation);