watch method
Opens a live stream which will yield the current matching model
periodically via a ReadResult.
Implementation
@override
Stream<ReadResult<T>> watch(WatchOperation<T> operation) =>
_guardedSync(() => _watch(operation), operation);
Opens a live stream which will yield the current matching model
periodically via a ReadResult.
@override
Stream<ReadResult<T>> watch(WatchOperation<T> operation) =>
_guardedSync(() => _watch(operation), operation);